==> zio-aws-apigatewayv2_3-5.17.130.2-sources.jar: zio/aws/apigatewayv2/model/DeleteVpcLinkRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteVpcLinkRequest(vpcLinkId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest = {
    import DeleteVpcLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
      .builder()
      .vpcLinkId(__string.unwrap(vpcLinkId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.wrap(buildAwsValue())
}
object DeleteVpcLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteVpcLinkRequest =
      zio.aws.apigatewayv2.model.DeleteVpcLinkRequest(vpcLinkId)
    def vpcLinkId: __string
    def getVpcLinkId: ZIO[Any, Nothing, __string] = ZIO.succeed(vpcLinkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ) extends zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly {
    override val vpcLinkId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.vpcLinkId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ): zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.17.163.1-sources.jar: zio/aws/apigatewayv2/model/DeleteVpcLinkRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteVpcLinkRequest(vpcLinkId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest = {
    import DeleteVpcLinkRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
      .builder()
      .vpcLinkId(vpcLinkId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.wrap(buildAwsValue())
}
object DeleteVpcLinkRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteVpcLinkRequest =
      zio.aws.apigatewayv2.model.DeleteVpcLinkRequest(vpcLinkId)
    def vpcLinkId: __string
    def getVpcLinkId: ZIO[Any, Nothing, __string] = ZIO.succeed(vpcLinkId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ) extends zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly {
    override val vpcLinkId: __string = impl.vpcLinkId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteVpcLinkRequest
  ): zio.aws.apigatewayv2.model.DeleteVpcLinkRequest.ReadOnly = new Wrapper(
    impl
  )
}
